@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "board.h"
 
@@ -24,7 +11,6 @@
 #include "generator.h"
 #include "language_settings.h"
 #include "letter.h"
-#include "random.h"
 #include "scores_dialog.h"
 #include "solver.h"
 #include "view.h"
@@ -34,118 +20,116 @@
 #include <QAction>
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <QEvent>
 #include <QGridLayout>
 #include <QGraphicsScene>
 #include <QHBoxLayout>
-#include <QKeyEvent>
 #include <QLabel>
 #include <QLineEdit>
 #include <QLineF>
 #include <QMessageBox>
-#include <QPainterPath>
 #include <QSettings>
 #include <QStyle>
 #include <QTabWidget>
 #include <QToolButton>
 #include <QVBoxLayout>
 
-#include <ctime>
+#include <algorithm>
 
 //-----------------------------------------------------------------------------
 
 Board::Board(QWidget* parent)
-: QWidget(parent), m_paused(false), m_wrong(false), m_valid(true), m_score_type(1), m_size(0), m_minimum(0), m_maximum(0), m_max_score(0), m_generator(0) {
+	: QWidget(parent)
+	, m_paused(false)
+	, m_wrong(false)
+	, m_wrong_typed(false)
+	, m_show_counts(1)
+	, m_size(0)
+	, m_minimum(0)
+	, m_maximum(0)
+	, m_max_score(0)
+	, m_generator(nullptr)
+{
 	m_generator = new Generator(this);
-	connect(m_generator, SIGNAL(finished()), this, SLOT(gameStarted()));
-	connect(m_generator, SIGNAL(optimizingStarted()), this, SIGNAL(optimizingStarted()));
-	connect(m_generator, SIGNAL(optimizingFinished()), this, SIGNAL(optimizingFinished()));
+	connect(m_generator, &Generator::finished, this, &Board::gameStarted);
+	connect(m_generator, &Generator::optimizingStarted, this, &Board::optimizingStarted);
+	connect(m_generator, &Generator::optimizingFinished, this, &Board::optimizingFinished);
 
-	m_view = new View(0, this);
+	m_view = new View(nullptr, this);
 
 	// Create clock and score widgets
 	m_clock = new Clock(this);
-	connect(m_clock, SIGNAL(finished()), this, SLOT(finish()));
+	connect(m_clock, &Clock::finished, this, &Board::finish);
 
 	m_score = new QLabel(this);
 
 	m_max_score_details = new QToolButton(this);
 	m_max_score_details->setAutoRaise(true);
-	m_max_score_details->setIconSize(QSize(16,16));
+	m_max_score_details->setIconSize(QSize(16, 16));
 	m_max_score_details->setIcon(QIcon::fromTheme("dialog-information", QIcon(":/dialog-information.png")));
 	m_max_score_details->setToolTip(tr("Details"));
-	connect(m_max_score_details, SIGNAL(clicked()), this, SLOT(showMaximumWords()));
+	connect(m_max_score_details, &QToolButton::clicked, this, &Board::showMaximumWords);
 
 	QHBoxLayout* score_layout = new QHBoxLayout;
-	score_layout->setMargin(0);
+	score_layout->setContentsMargins(0, 0, 0, 0);
 	score_layout->addWidget(m_score);
 	score_layout->addWidget(m_max_score_details);
 
 	// Create guess widgets
 	m_guess = new QLineEdit(this);
 	m_guess->setDisabled(true);
-	m_guess->setMaxLength(16);
+	m_guess->setMaxLength(25);
 	m_guess->installEventFilter(this);
-	connect(m_guess, SIGNAL(textEdited(const QString&)), this, SLOT(guessChanged()));
-	connect(m_guess, SIGNAL(returnPressed()), this, SLOT(guess()));
-	connect(m_view, SIGNAL(mousePressed()), m_guess, SLOT(setFocus()));
+	m_guess->setClearButtonEnabled(true);
+	connect(m_guess, &QLineEdit::textEdited, this, &Board::guessChanged);
+	connect(m_guess, &QLineEdit::returnPressed, this, &Board::guess);
+	connect(m_view, &View::mousePressed, m_guess, qOverload<>(&QLineEdit::setFocus));
 
 	int size = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
 
-	m_clear_button = new QToolButton(this);
-	m_clear_button->setAutoRaise(true);
-	m_clear_button->setIconSize(QSize(size,size));
-	QIcon clear_fallback(":/tango/32x32/actions/edit-clear.png");
-	clear_fallback.addFile(":/tango/24x24/actions/edit-clear.png");
-	clear_fallback.addFile(":/tango/22x22/actions/edit-clear.png");
-	clear_fallback.addFile(":/tango/16x16/actions/edit-clear.png");
-	m_clear_button->setIcon(QIcon::fromTheme("edit-clear", clear_fallback));
-	m_clear_button->setToolTip(tr("Clear"));
-	m_clear_button->setEnabled(false);
-	connect(m_clear_button, SIGNAL(clicked()), this, SLOT(clearGuess()));
-
 	m_guess_button = new QToolButton(this);
 	m_guess_button->setAutoRaise(true);
-	m_guess_button->setIconSize(QSize(size,size));
-	QIcon guess_fallback(":/tango/32x32/actions/list-add.png");
+	m_guess_button->setIconSize(QSize(size, size));
+	QIcon guess_fallback(":/tango/64x64/actions/list-add.png");
+	guess_fallback.addFile(":/tango/48x48/actions/list-add.png");
+	guess_fallback.addFile(":/tango/32x32/actions/list-add.png");
 	guess_fallback.addFile(":/tango/24x24/actions/list-add.png");
 	guess_fallback.addFile(":/tango/22x22/actions/list-add.png");
 	guess_fallback.addFile(":/tango/16x16/actions/list-add.png");
 	m_guess_button->setIcon(QIcon::fromTheme("list-add", guess_fallback));
 	m_guess_button->setToolTip(tr("Guess"));
 	m_guess_button->setEnabled(false);
-	connect(m_guess_button, SIGNAL(clicked()), this, SLOT(guess()));
+	connect(m_guess_button, &QToolButton::clicked, this, &Board::guess);
 
 	QHBoxLayout* guess_layout = new QHBoxLayout;
 	guess_layout->setSpacing(0);
-	guess_layout->addStretch();
 	guess_layout->addWidget(m_guess);
-	guess_layout->addWidget(m_clear_button);
 	guess_layout->addWidget(m_guess_button);
-	guess_layout->addStretch();
 
 	// Create word lists
 	m_found = new WordTree(this);
 	m_found->setFocusPolicy(Qt::TabFocus);
-	connect(m_found, SIGNAL(itemSelectionChanged()), this, SLOT(wordSelected()));
+	connect(m_found, &WordTree::itemSelectionChanged, this, &Board::wordSelected);
 
 	m_missed = new WordTree(this);
 	m_missed->setFocusPolicy(Qt::TabFocus);
 	m_missed->hide();
-	connect(m_missed, SIGNAL(itemSelectionChanged()), this, SLOT(wordSelected()));
+	connect(m_missed, &WordTree::itemSelectionChanged, this, &Board::wordSelected);
 
 	QWidget* found_tab = new QWidget(this);
 	QVBoxLayout* found_layout = new QVBoxLayout(found_tab);
 	found_layout->setSpacing(0);
-	found_layout->setMargin(0);
+	found_layout->setContentsMargins(0, 0, 0, 0);
 	found_layout->addLayout(guess_layout);
 	found_layout->addWidget(m_found);
 
 	m_tabs = new QTabWidget(this);
+	m_tabs->setUsesScrollButtons(false);
 	m_tabs->addTab(found_tab, tr("Found"));
-	connect(m_tabs, SIGNAL(currentChanged(int)), this, SLOT(clearGuess()));
+	connect(m_tabs, &QTabWidget::currentChanged, this, &Board::clearGuess);
 
-	int width = guess_layout->sizeHint().width();
+	m_tabs->addTab(m_missed, tr("Missed"));
+	const int width = std::max(guess_layout->sizeHint().width(), m_tabs->minimumSizeHint().width());
+	m_tabs->removeTab(1);
 	m_tabs->setFixedWidth(width);
 
 	m_counts = new WordCounts(this);
@@ -154,7 +138,6 @@ Board::Board(QWidget* parent)
 	// Lay out board
 	QGridLayout* layout = new QGridLayout(this);
 	layout->setColumnStretch(1, 1);
-	layout->setColumnStretch(1, 1);
 	layout->setRowStretch(1, 1);
 	layout->addWidget(m_tabs, 0, 0, 3, 1);
 	layout->addWidget(m_clock, 0, 1, Qt::AlignCenter);
@@ -165,7 +148,10 @@ Board::Board(QWidget* parent)
 
 //-----------------------------------------------------------------------------
 
-Board::~Board() {
+Board::~Board()
+{
+	m_generator->cancel();
+
 	QSettings game;
 	if (isFinished()) {
 		// Clear current game
@@ -182,7 +168,7 @@ Board::~Board() {
 
 		QVariantList positions;
 		QString word;
-		foreach (const QPoint& position, m_positions) {
+		for (const QPoint& position : std::as_const(m_positions)) {
 			positions.append(position);
 			word.append(m_cells[position.x()][position.y()]->text().toUpper());
 		}
@@ -200,20 +186,30 @@ Board::~Board() {
 
 //-----------------------------------------------------------------------------
 
-bool Board::isFinished() const {
+bool Board::isFinished() const
+{
 	return m_clock->isFinished();
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::abort() {
+void Board::abort()
+{
 	m_generator->cancel();
 	m_clock->stop();
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::generate(const QSettings& game) {
+bool Board::generate(const QSettings& game)
+{
+	constexpr unsigned int TANGLET_FILE_VERSION = 3;
+
+	// Verify version
+	if (game.value("Version").toUInt() > TANGLET_FILE_VERSION) {
+		return false;
+	}
+
 	// Find values
 	int size = qBound(4, game.value("Size").toInt(), 5);
 	int density = qBound(0, game.value("Density").toInt(), 3);
@@ -225,15 +221,14 @@ void Board::generate(const QSettings& game) {
 	}
 	int timer = qBound(0, game.value("TimerMode").toInt(), Clock::TotalTimers - 1);
 	QStringList letters = game.value("Letters").toStringList();
-	unsigned int seed = Random(time(0)).nextInt();
 
-	LanguageSettings settings;
-	int language = game.value("Language", settings.language()).toInt();
-	QString dice = game.value("Dice", settings.dice()).toString();
-	QString words = game.value("Words", settings.words()).toString();
-	QString dictionary = game.value("Dictionary", settings.dictionary()).toString();
+	// Verify board size
+	if (game.contains("Version") && ((size * size) != letters.size())) {
+		return false;
+	}
 
-	bool is_hebrew = (language == QLocale::Hebrew);
+	const LanguageSettings language(game);
+	const bool is_hebrew = (QLocale(language.language()).language() == QLocale::Hebrew);
 	m_found->setHebrew(is_hebrew);
 	m_missed->setHebrew(is_hebrew);
 
@@ -241,15 +236,15 @@ void Board::generate(const QSettings& game) {
 	{
 		QSettings settings;
 		settings.beginGroup("Current");
-		settings.setValue("Version", 2);
+		settings.setValue("Version", TANGLET_FILE_VERSION);
 		settings.setValue("Size", size);
 		settings.setValue("Density", density);
 		settings.setValue("Minimum", minimum);
 		settings.setValue("TimerMode", timer);
-		settings.setValue("Language", language);
-		settings.setValue("Dice", dice);
-		settings.setValue("Words", words);
-		settings.setValue("Dictionary", dictionary);
+		settings.setValue("Locale", language.language());
+		settings.setValue("Dice", language.dice());
+		settings.setValue("Words", language.words());
+		settings.setValue("Dictionary", language.dictionary());
 		if (!letters.isEmpty()) {
 			settings.setValue("Letters", letters);
 		}
@@ -257,12 +252,15 @@ void Board::generate(const QSettings& game) {
 
 	// Create new game
 	m_generator->cancel();
-	m_generator->create(density, size, minimum, timer, letters, seed);
+	m_generator->create(density, size, minimum, timer, letters);
+
+	return true;
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::setPaused(bool pause) {
+void Board::setPaused(bool pause)
+{
 	if (isFinished()) {
 		return;
 	}
@@ -278,23 +276,26 @@ void Board::setPaused(bool pause) {
 
 //-----------------------------------------------------------------------------
 
-QString Board::sizeToString(int size) {
+QString Board::sizeToString(int size)
+{
 	return (size == 4) ? tr("Normal") : tr("Large");
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::setShowMaximumScore(QAction* show) {
+void Board::setShowMaximumScore(QAction* show)
+{
 	int score_type = show->data().toInt();
 	QSettings().setValue("ShowMaximumScore", score_type);
-	m_score_type = score_type;
-	m_max_score_details->setVisible(isFinished() && m_score_type && m_clock->timer() == Clock::Allotment);
+	m_show_counts = score_type;
+	m_max_score_details->setVisible(isFinished() && m_show_counts && m_clock->timer() == Clock::Allotment);
 	updateScore();
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::setShowMissedWords(bool show) {
+void Board::setShowMissedWords(bool show)
+{
 	QSettings().setValue("ShowMissed", show);
 	if (show) {
 		if (m_tabs->count() == 1) {
@@ -311,20 +312,16 @@ void Board::setShowMissedWords(bool show) {
 
 //-----------------------------------------------------------------------------
 
-void Board::setShowWordCounts(bool show) {
+void Board::setShowWordCounts(bool show)
+{
 	QSettings().setValue("ShowWordCounts", show);
 	m_counts->setVisible(show);
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::updateScoreColor() {
-	updateScore();
-}
-
-//-----------------------------------------------------------------------------
-
-void Board::gameStarted() {
+void Board::gameStarted()
+{
 	// Load settings
 	QSettings settings;
 	settings.beginGroup("Current");
@@ -332,7 +329,7 @@ void Board::gameStarted() {
 	m_clock->setTimer(m_generator->timer());
 	if (m_generator->size() != m_size) {
 		m_size = m_generator->size();
-		m_cells = QVector<QVector<Letter*> >(m_size, QVector<Letter*>(m_size));
+		m_cells = QList<QList<Letter*>>(m_size, QList<Letter*>(m_size));
 		m_maximum = m_size * m_size;
 		m_guess->setMaxLength(m_maximum);
 	}
@@ -354,12 +351,13 @@ void Board::gameStarted() {
 	f.setPointSize(20);
 	QFontMetrics metrics(f);
 	int letter_size = 0;
-	foreach (const QStringList& die, m_generator->dice(m_size)) {
-		foreach (const QString& side, die) {
-			letter_size = qMax(letter_size, metrics.width(side));
+	const auto dice = m_generator->dice(m_size);
+	for (const QStringList& die : dice) {
+		for (const QString& side : die) {
+			letter_size = std::max(letter_size, metrics.boundingRect(side).width());
 		}
 	}
-	int cell_size = qMax(metrics.height(), letter_size) + 10;
+	int cell_size = std::max(metrics.height(), letter_size) + 10;
 	int cell_padding_size = cell_size + 4;
 	int board_size = (m_size * cell_padding_size) + 8;
 
@@ -370,18 +368,18 @@ void Board::gameStarted() {
 	m_view->fitInView(m_view->sceneRect(), Qt::KeepAspectRatio);
 
 	BeveledRect* rect = new BeveledRect(board_size);
-	rect->setColor("#0057ae");
+	rect->setColor(QColor(0, 0x57, 0xae));
 	scene->addItem(rect);
 
 	// Create cells
 	for (int r = 0; r < m_size; ++r) {
 		for (int c = 0; c < m_size; ++c) {
-			Letter* cell = new Letter(f, cell_size, QPoint(c,r));
+			Letter* cell = new Letter(f, cell_size, QPoint(c, r));
 			cell->setText(m_letters.at((r * m_size) + c));
 			cell->moveBy((c * cell_padding_size) + 6, (r * cell_padding_size) + 6);
 			scene->addItem(cell);
 			m_cells[c][r] = cell;
-			connect(cell, SIGNAL(clicked(Letter*)), this, SLOT(letterClicked(Letter*)));
+			connect(cell, &Letter::clicked, this, &Board::letterClicked);
 		}
 	}
 
@@ -391,8 +389,7 @@ void Board::gameStarted() {
 
 	// Clear previous words
 	m_paused = false;
-	emit pauseAvailable(true);
-	m_clear_button->setEnabled(true);
+	Q_EMIT pauseAvailable(true);
 	m_guess_button->setEnabled(true);
 	m_positions.clear();
 	m_found->removeAll();
@@ -405,26 +402,25 @@ void Board::gameStarted() {
 	clearHighlight();
 
 	// Add solutions
-	QList<QString> solutions = m_solutions.keys();
-	foreach (const QString& solution, solutions) {
-		m_missed->addWord(solution);
+	for (auto i = m_solutions.cbegin(), end = m_solutions.cend(); i != end; ++i) {
+		m_missed->addWord(i.key());
 	}
 
 	// Add found words
-	QStringList found = settings.value("Found").toStringList();
-	foreach (const QString& text, found) {
+	const QStringList found = settings.value("Found").toStringList();
+	for (const QString& text : found) {
 		QTreeWidgetItem* item = m_found->findItems(text, Qt::MatchExactly, 2).value(0);
 		if (m_missed->findItems(text, Qt::MatchExactly, 2).value(0) && !item) {
-			item = m_found->addWord(text);
-			delete m_missed->findItems(text, Qt::MatchExactly, 2).first();
+			m_found->addWord(text);
+			delete m_missed->findItems(text, Qt::MatchExactly, 2).constFirst();
 			m_counts->findWord(text);
 		}
 	}
 
 	// Add guess
 	m_guess->setText(settings.value("Guess").toString());
-	QVariantList positions = settings.value("GuessPositions").toList();
-	foreach (const QVariant& position, positions) {
+	const QVariantList positions = settings.value("GuessPositions").toList();
+	for (const QVariant& position : positions) {
 		m_positions.append(position.toPoint());
 	}
 
@@ -437,7 +433,7 @@ void Board::gameStarted() {
 	}
 
 	// Start game
-	emit started();
+	Q_EMIT started();
 	if (m_missed->topLevelItemCount() > 0) {
 		m_clock->start();
 		if (settings.contains("TimerDetails/Time")) {
@@ -454,94 +450,101 @@ void Board::gameStarted() {
 
 //-----------------------------------------------------------------------------
 
-void Board::clearGuess() {
-	m_valid = true;
+void Board::clearGuess()
+{
+	m_wrong_typed = false;
 	m_wrong = false;
 	m_positions.clear();
 	clearHighlight();
 	updateClickableStatus();
 	m_guess->clear();
-	m_found->clearSelection();
-	m_missed->clearSelection();
+	m_found->setCurrentItem(nullptr);
+	m_missed->setCurrentItem(nullptr);
 	m_guess->setFocus();
 	updateButtons();
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::guess() {
-	if (!isFinished() && !m_paused) {
-		QString text = m_guess->text().trimmed().toUpper();
-		if (text.isEmpty() || text.length() < m_minimum || text.length() > m_maximum || !m_valid || m_positions.isEmpty() || m_wrong) {
-			return;
-		}
-		if (!m_solutions.contains(text)) {
-			m_wrong = true;
-			highlightWord();
-			updateButtons();
-			m_clock->addIncorrectWord(Solver::score(text));
-			return;
+void Board::guess()
+{
+	if (isFinished() || m_paused || m_positions.isEmpty() || m_wrong_typed || m_wrong) {
+		return;
+	}
+
+	const QString text = m_guess->text().trimmed().toUpper();
+	if (text.isEmpty() || (text.length() < m_minimum) || (text.length() > m_maximum)) {
+		return;
+	}
+	if (!m_solutions.contains(text)) {
+		m_wrong = true;
+		highlightWord();
+		updateButtons();
+		m_clock->addIncorrectWord(Solver::score(text));
+		return;
+	}
+
+	// Create found item
+	QTreeWidgetItem* item = m_found->findItems(text, Qt::MatchExactly, 2).value(0);
+	if (!item) {
+		item = m_found->addWord(text);
+		delete m_missed->findItems(item->text(2), Qt::MatchExactly, 2).constFirst();
+
+		m_clock->addWord(item->data(0, Qt::UserRole).toInt());
+		updateScore();
+
+		QList<QList<QPoint>>& solutions = m_solutions[text];
+		const int index = solutions.indexOf(m_positions);
+		if (index != -1) {
+			solutions.move(index, 0);
+		} else {
+			solutions.prepend(m_positions);
 		}
 
-		// Create found item
-		QTreeWidgetItem* item = m_found->findItems(text, Qt::MatchExactly, 2).value(0);
-		if (item == 0) {
-			item = m_found->addWord(text);
-			delete m_missed->findItems(item->text(2), Qt::MatchExactly, 2).first();
+		m_counts->findWord(text);
+	}
+	m_found->scrollToItem(item);
+	m_found->setCurrentItem(nullptr);
 
-			m_clock->addWord(item->data(0, Qt::UserRole).toInt());
-			updateScore();
+	// Clear guess
+	clearGuess();
 
-			QList<QList<QPoint> >& solutions = m_solutions[text];
-			int index = solutions.indexOf(m_positions);
-			if (index != -1) {
-				solutions.move(index, 0);
-			} else {
-				solutions.prepend(m_positions);
-			}
-
-			m_counts->findWord(text);
+	// Handle finding all of the words
+	if (m_missed->topLevelItemCount() == 0) {
+		// Increase score
+		for (int i = 0; i < m_found->topLevelItemCount(); ++i) {
+			QTreeWidgetItem* found_item = m_found->topLevelItem(i);
+			found_item->setData(0, Qt::UserRole, found_item->data(0, Qt::UserRole).toInt() + 1);
 		}
-		m_found->scrollToItem(item, QAbstractItemView::PositionAtCenter);
-		m_found->clearSelection();
 
-		// Clear guess
-		clearGuess();
-
-		// Handle finding all of the words
-		if (m_missed->topLevelItemCount() == 0) {
-			// Increase score
-			for (int i = 0; i < m_found->topLevelItemCount(); ++i) {
-				QTreeWidgetItem* item = m_found->topLevelItem(i);
-				item->setData(0, Qt::UserRole, item->data(0, Qt::UserRole).toInt() + 1);
-			}
-
-			// Stop the game
-			m_clock->stop();
-		}
+		// Stop the game
+		m_clock->stop();
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::guessChanged() {
-	m_valid = true;
+void Board::guessChanged()
+{
+	m_wrong_typed = false;
 	m_wrong = false;
 	clearHighlight();
-	m_found->clearSelection();
+	m_found->setCurrentItem(nullptr);
 
 	QString word = m_guess->text().trimmed().toUpper();
 	if (!word.isEmpty()) {
-		int pos = m_guess->cursorPosition();
+		int cursor_pos = m_guess->cursorPosition();
 		m_guess->setText(word);
-		m_guess->setCursorPosition(pos);
+		m_guess->setCursorPosition(cursor_pos);
+		QTreeWidgetItem* item = m_found->findItems(word, Qt::MatchStartsWith, 2).value(0);
+		m_found->scrollToItem(item, QAbstractItemView::PositionAtTop);
 
 		Trie trie(word);
 		Solver solver(trie, m_size, 0);
 		solver.solve(m_letters);
-		QList<QList<QPoint> > solutions = m_solutions.value(word, solver.solutions().value(word));
-		m_valid = !solutions.isEmpty();
-		if (m_valid) {
+		QList<QList<QPoint>> solutions = m_solutions.value(word, solver.solutions().value(word));
+		m_wrong_typed = solutions.isEmpty();
+		if (!m_wrong_typed) {
 			int index = 0;
 			int matched = -1;
 			int difference = INT_MAX;
@@ -555,7 +558,7 @@ void Board::guessChanged() {
 
 				// Find how many cells match and are in order between solution and m_positions
 				const QList<QPoint>& solution = solutions.at(i);
-				foreach (const QPoint& cell, solution) {
+				for (const QPoint& cell : solution) {
 					int pos = m_positions.indexOf(cell);
 					if (pos != -1) {
 						match++;
@@ -597,27 +600,28 @@ void Board::guessChanged() {
 
 //-----------------------------------------------------------------------------
 
-void Board::finish() {
+void Board::finish()
+{
 	m_clock->setText((m_missed->topLevelItemCount() == 0 && m_found->topLevelItemCount() > 0) ? tr("Success") : tr("Game Over"));
 
 	clearGuess();
 	m_found->setColumnHidden(1, false);
 	m_guess->setDisabled(true);
-	m_clear_button->setDisabled(true);
 	m_guess_button->setDisabled(true);
 	m_guess->setEchoMode(QLineEdit::NoEcho);
 	m_guess->releaseKeyboard();
 	m_tabs->setTabEnabled(1, true);
-	m_max_score_details->setVisible(m_score_type && m_clock->timer() == Clock::Allotment);
-	emit pauseAvailable(false);
+	m_max_score_details->setVisible(m_show_counts && m_clock->timer() == Clock::Allotment);
+	Q_EMIT pauseAvailable(false);
 
 	int score = updateScore();
-	emit finished(score);
+	Q_EMIT finished(score, m_max_score);
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::wordSelected() {
+void Board::wordSelected()
+{
 	QList<QTreeWidgetItem*> items;
 	if (m_tabs->currentWidget() == m_missed) {
 		items = m_missed->selectedItems();
@@ -642,13 +646,15 @@ void Board::wordSelected() {
 
 //-----------------------------------------------------------------------------
 
-void Board::letterClicked(Letter* letter) {
-
+void Board::letterClicked(Letter* letter)
+{
 	// Handle adding a letter to the guess
 	if (!m_positions.contains(letter->position())) {
 		QString word = m_guess->text().trimmed().toUpper();
 		word.append(letter->text().toUpper());
 		m_guess->setText(word);
+		QTreeWidgetItem* item = m_found->findItems(word, Qt::MatchStartsWith, 2).value(0);
+		m_found->scrollToItem(item, QAbstractItemView::PositionAtTop);
 
 		m_wrong = false;
 		m_positions.append(letter->position());
@@ -673,7 +679,7 @@ void Board::letterClicked(Letter* letter) {
 		updateClickableStatus();
 
 		QString word;
-		foreach (const QPoint& position, m_positions) {
+		for (const QPoint& position : std::as_const(m_positions)) {
 			word.append(m_cells[position.x()][position.y()]->text().toUpper());
 		}
 		m_guess->setText(word);
@@ -687,7 +693,8 @@ void Board::letterClicked(Letter* letter) {
 
 //-----------------------------------------------------------------------------
 
-void Board::highlightWord(const QList<QPoint>& positions, const QColor& color) {
+void Board::highlightWord(const QList<QPoint>& positions, const QColor& color)
+{
 	Q_ASSERT(!positions.isEmpty());
 
 	m_cells[positions.at(0).x()][positions.at(0).y()]->setColor(color);
@@ -711,7 +718,8 @@ void Board::highlightWord(const QList<QPoint>& positions, const QColor& color) {
 
 //-----------------------------------------------------------------------------
 
-void Board::highlightWord() {
+void Board::highlightWord()
+{
 	QString guess = m_guess->text();
 	if (guess.isEmpty()) {
 		return;
@@ -719,17 +727,17 @@ void Board::highlightWord() {
 
 	QPalette p = palette();
 	if (!m_wrong) {
-		if (!m_valid) {
+		if (m_wrong_typed) {
 			p.setColor(m_guess->foregroundRole(), Qt::white);
 			p.setColor(m_guess->backgroundRole(), Qt::red);
 		} else if (!m_found->findItems(guess, Qt::MatchExactly).isEmpty()) {
 			p.setColor(m_guess->foregroundRole(), Qt::white);
-			p.setColor(m_guess->backgroundRole(), "#ffaa00");
-			highlightWord(m_positions, "#ffaa00");
+			p.setColor(m_guess->backgroundRole(), QColor(0xff, 0xaa, 0));
+			highlightWord(m_positions, QColor(0xff, 0xaa, 0));
 		} else if (m_positions.count() < m_minimum) {
-			highlightWord(m_positions, "#bfd9ff");
+			highlightWord(m_positions, QColor(0xbf, 0xd9, 0xff));
 		} else {
-			highlightWord(m_positions, "#80b3ff");
+			highlightWord(m_positions, QColor(0x80, 0xb3, 0xff));
 		}
 	} else {
 		p.setColor(m_guess->foregroundRole(), Qt::white);
@@ -743,8 +751,9 @@ void Board::highlightWord() {
 
 //-----------------------------------------------------------------------------
 
-void Board::clearHighlight() {
-	QColor color = !isFinished() ? Qt::white : QColor("#aaa");
+void Board::clearHighlight()
+{
+	QColor color = !isFinished() ? Qt::white : QColor(0xaa, 0xaa, 0xaa);
 	for (int c = 0; c < m_size; ++c) {
 		for (int r = 0; r < m_size; ++r) {
 			m_cells[c][r]->setColor(color);
@@ -757,25 +766,27 @@ void Board::clearHighlight() {
 
 //-----------------------------------------------------------------------------
 
-void Board::selectGuess() {
+void Board::selectGuess()
+{
 	QTreeWidgetItem* item = m_found->findItems(m_guess->text(), Qt::MatchExactly, 0).value(0);
-	if (item != 0) {
+	if (item) {
 		m_found->setCurrentItem(item);
-		m_found->scrollToItem(item, QAbstractItemView::PositionAtCenter);
+		m_found->scrollToItem(item);
 	} else {
-		m_found->clearSelection();
+		m_found->setCurrentItem(nullptr);
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-int Board::updateScore() {
+int Board::updateScore()
+{
 	int score = 0;
 	for (int i = 0; i < m_found->topLevelItemCount(); ++i) {
 		score += m_found->topLevelItem(i)->data(0, Qt::UserRole).toInt();
 	}
 
-	if (m_score_type == 2 || (m_score_type == 1 && isFinished())) {
+	if (m_show_counts == 2 || (m_show_counts == 1 && isFinished())) {
 		if (score > 3) {
 			m_score->setText(tr("%1 of %n point(s)", "", m_max_score).arg(score));
 		} else if (score == 3) {
@@ -795,7 +806,7 @@ int Board::updateScore() {
 
 	QFont f = font();
 	QPalette p = palette();
-	switch (ScoresDialog::isHighScore(score)) {
+	switch (ScoresDialog::isHighScore(score, m_clock->timer())) {
 	case 2:
 		f.setBold(true);
 		p.setColor(m_score->foregroundRole(), Qt::blue);
@@ -814,7 +825,8 @@ int Board::updateScore() {
 
 //-----------------------------------------------------------------------------
 
-void Board::updateClickableStatus() {
+void Board::updateClickableStatus()
+{
 	bool finished = isFinished();
 	bool has_word = !m_positions.isEmpty() && !finished;
 	bool clickable = !has_word && !finished;
@@ -825,19 +837,19 @@ void Board::updateClickableStatus() {
 		}
 	}
 
-	if (has_word && m_valid) {
-		const QPoint& position = m_positions.last();
-		int min_x = qMax(position.x() - 1, 0);
-		int max_x = qMin(position.x() + 2, m_size);
-		int min_y = qMax(position.y() - 1, 0);
-		int max_y = qMin(position.y() + 2, m_size);
+	if (has_word && !m_wrong_typed) {
+		const QPoint& last_position = m_positions.last();
+		int min_x = std::max(last_position.x() - 1, 0);
+		int max_x = std::min(last_position.x() + 2, m_size);
+		int min_y = std::max(last_position.y() - 1, 0);
+		int max_y = std::min(last_position.y() + 2, m_size);
 		for (int y = min_y; y < max_y; ++y) {
 			for (int x = min_x; x < max_x; ++x) {
 				m_cells[x][y]->setClickable(true);
 			}
 		}
 
-		foreach (const QPoint& position, m_positions) {
+		for (const QPoint& position : std::as_const(m_positions)) {
 			m_cells[position.x()][position.y()]->setClickable(true);
 		}
 	}
@@ -845,33 +857,40 @@ void Board::updateClickableStatus() {
 
 //-----------------------------------------------------------------------------
 
-void Board::updateButtons() {
+void Board::updateButtons()
+{
 	QString text = m_guess->text();
 	bool has_guess = !text.isEmpty();
-	m_clear_button->setEnabled(has_guess);
-	m_guess_button->setEnabled(has_guess && text.length() >= m_minimum && text.length() <= m_maximum && m_valid && !m_positions.isEmpty() && !m_wrong);
+	m_guess_button->setEnabled(has_guess
+			&& (text.length() >= m_minimum)
+			&& (text.length() <= m_maximum)
+			&& !m_positions.isEmpty()
+			&& !m_wrong_typed
+			&& !m_wrong);
 }
 
 //-----------------------------------------------------------------------------
 
-void Board::showMaximumWords() {
+void Board::showMaximumWords()
+{
 	QDialog dialog(window(), Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint);
 	dialog.setWindowTitle(tr("Details"));
 
 	QList<int> scores;
-	foreach (const QString& word, m_solutions.keys()) {
-		scores.append(Solver::score(word));
+	for (auto i = m_solutions.cbegin(), end = m_solutions.cend(); i != end; ++i) {
+		scores.append(Solver::score(i.key()));
 	}
-	qSort(scores.begin(), scores.end(), qGreater<int>());
+	std::sort(scores.begin(), scores.end(), std::greater<int>());
 	scores = scores.mid(0, 30);
 
 	QLabel* message = new QLabel(tr("The maximum score was calculated from the following thirty words:"), this);
 	message->setWordWrap(true);
 
 	WordTree* words = new WordTree(this);
+	words->setTrie(m_generator->trie());
 	words->setDictionary(m_generator->dictionary());
-	QList<QTreeWidget*> trees = QList<QTreeWidget*>() << m_found << m_missed;
-	foreach (QTreeWidget* tree, trees) {
+	const QList<QTreeWidget*> trees{ m_found, m_missed };
+	for (QTreeWidget* tree : trees) {
 		for (int i = 0; i < tree->topLevelItemCount(); ++i) {
 			QTreeWidgetItem* item = tree->topLevelItem(i);
 			int index = scores.indexOf(item->data(0, Qt::UserRole).toInt());
@@ -884,7 +903,7 @@ void Board::showMaximumWords() {
 
 	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Horizontal, &dialog);
 	buttons->setCenterButtons(style()->styleHint(QStyle::SH_MessageBox_CenterButtons));
-	connect(buttons, SIGNAL(accepted()), &dialog, SLOT(accept()));
+	connect(buttons, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
 
 	QVBoxLayout* layout = new QVBoxLayout(&dialog);
 	layout->addWidget(message);
