@@ -1,28 +1,14 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "generator.h"
 
 #include "clock.h"
 #include "gzip.h"
 #include "language_settings.h"
-#include "random.h"
 #include "solver.h"
 #include "trie.h"
 
@@ -32,86 +18,119 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
-#include <QStandardPaths>
-#else
-#include <QDesktopServices>
-#endif
+#include <QSettings>
 #include <QTextStream>
 
 //-----------------------------------------------------------------------------
 
 namespace
 {
-	struct State
+
+/**
+ * @brief The State class represents a current game being built.
+ */
+struct State
+{
+	/**
+	 * Constructs a state instance.
+	 * @param dice the dice used to fill the board
+	 * @param solver the solve used to check the board for solutions
+	 * @param target the target amount of words
+	 * @param random the random number generator
+	 */
+	State(const QList<QStringList>& dice, Solver* solver, int target, QRandomGenerator* random)
+		: m_dice(dice)
+		, m_solver(solver)
+		, m_target(target)
+		, m_random(random)
 	{
-		State(const QList<QStringList>& dice, Solver* solver, int target, Random* random)
-			: m_dice(dice), m_solver(solver), m_target(target), m_random(random)
-		{
-		}
+	}
 
-		int delta() const
-		{
-			return m_delta;
-		}
+	/**
+	 * @return how far off the amount of words on the board is from the target amount of words
+	 */
+	int delta() const
+	{
+		return m_delta;
+	}
 
-		QStringList letters() const
-		{
-			return m_letters;
-		}
+	/**
+	 * @return the board layout
+	 */
+	QStringList letters() const
+	{
+		return m_letters;
+	}
 
-		void permute()
-		{
-			if (m_random->nextInt(2) == 1) {
-				int index = m_random->nextInt(m_dice.count());
-				m_random->shuffle(m_dice[index]);
-				m_letters[index] = m_dice.at(index).first();
-			} else {
-				int index1 = m_random->nextInt(m_dice.count());
-				int index2 = m_random->nextInt(m_dice.count());
-				m_dice.swap(index1, index2);
-				m_letters.swap(index1, index2);
-			}
-			solve();
+	/**
+	 * Flips individual dice to tweak the board and searches it for solutions.
+	 */
+	void permute()
+	{
+		if (m_random->bounded(2)) {
+			const int index = m_random->bounded(m_dice.count());
+			QStringList& die = m_dice[index];
+			std::shuffle(die.begin(), die.end(), *m_random);
+			m_letters[index] = m_dice.at(index).first();
+		} else {
+			const int index1 = m_random->bounded(m_dice.count());
+			const int index2 = m_random->bounded(m_dice.count());
+			m_dice.swapItemsAt(index1, index2);
+			m_letters.swapItemsAt(index1, index2);
 		}
+		solve();
+	}
 
-		void roll()
-		{
-			m_random->shuffle(m_dice);
-			m_letters.clear();
-			int count = m_dice.count();
-			for (int i = 0; i < count; ++i) {
-				QStringList& die = m_dice[i];
-				m_random->shuffle(die);
-				m_letters += die.first();
-			}
-			solve();
+	/**
+	 * Rolls the dice to generate a new board and searches it for solutions.
+	 */
+	void roll()
+	{
+		std::shuffle(m_dice.begin(), m_dice.end(), *m_random);
+		m_letters.clear();
+		int count = m_dice.count();
+		for (int i = 0; i < count; ++i) {
+			QStringList& die = m_dice[i];
+			std::shuffle(die.begin(), die.end(), *m_random);
+			m_letters += die.first();
 		}
+		solve();
+	}
 
-	private:
-		void solve()
-		{
-			m_solver->solve(m_letters);
-			int words = m_solver->count();
-			m_delta = abs(words - m_target);
-		}
+private:
+	/**
+	 * Searches the board for solutions and determines how far off the amount of words is from the
+	 * target amount of words.
+	 */
+	void solve()
+	{
+		m_solver->solve(m_letters);
+		int words = m_solver->count();
+		m_delta = abs(words - m_target);
+	}
+
+private:
+	QList<QStringList> m_dice; /**< the dice used to generate a layout */
+	QStringList m_letters; /**< the generated layout */
+	Solver* m_solver; /**< solves the generated layout */
+	int m_target; /**< the target number of words on generated board */
+	int m_delta; /**< how far the actual number of words is from the target */
+	QRandomGenerator* m_random; /**< random number generator */
+};
 
-	private:
-		QList<QStringList> m_dice;
-		QStringList m_letters;
-		int m_delta;
-		Solver* m_solver;
-		int m_target;
-		Random* m_random;
-	};
 }
 
 //-----------------------------------------------------------------------------
 
-Generator::Generator(QObject* parent) :
-	QThread(parent),
-	m_max_score(0),
-	m_canceled(false)
+QString Generator::m_cache_path;
+
+//-----------------------------------------------------------------------------
+
+Generator::Generator(QObject* parent)
+	: QThread(parent)
+	, m_random(QRandomGenerator::securelySeeded())
+	, m_max_score(0)
+	, m_canceled(false)
 {
 }
 
@@ -120,14 +139,14 @@ Generator::Generator(QObject* parent) :
 void Generator::cancel()
 {
 	blockSignals(true);
-	m_canceled = true;
+	m_canceled.store(true, std::memory_order_relaxed);
 	wait();
 	blockSignals(false);
 }
 
 //-----------------------------------------------------------------------------
 
-void Generator::create(int density, int size, int minimum, int timer, const QStringList& letters, unsigned int seed)
+void Generator::create(int density, int size, int minimum, int timer, const QStringList& letters)
 {
 	m_density = density;
 	m_size = size;
@@ -135,8 +154,7 @@ void Generator::create(int density, int size, int minimum, int timer, const QStr
 	m_timer = timer;
 	m_max_words = (m_timer != Clock::Allotment) ? -1 : 30;
 	m_letters = letters;
-	m_seed = seed;
-	m_canceled = false;
+	m_canceled.store(false, std::memory_order_relaxed);
 	m_max_score = 0;
 	m_solutions.clear();
 	start();
@@ -160,9 +178,8 @@ void Generator::run()
 		return;
 	}
 
-	Random random(m_seed);
 	if (m_density == 3) {
-		m_density = random.nextInt(3);
+		m_density = m_random.bounded(0, 3);
 	}
 
 	// Find word range
@@ -187,7 +204,7 @@ void Generator::run()
 
 	// Create board state
 	solver.setTrackPositions(false);
-	State current(dice(m_size), &solver, words_target, &random);
+	State current(dice(m_size), &solver, words_target, &m_random);
 	current.roll();
 	State next = current;
 
@@ -219,7 +236,7 @@ void Generator::run()
 				loops = 0;
 			}
 		}
-	} while (!m_canceled && (current.delta() > words_range));
+	} while (!m_canceled.load(std::memory_order_relaxed) && (current.delta() > words_range));
 
 	// Store solutions for generated board
 	m_letters = current.letters();
@@ -235,7 +252,9 @@ void Generator::update()
 {
 	m_error.clear();
 
-	LanguageSettings settings("Current");
+	QSettings config;
+	config.beginGroup("Current");
+	LanguageSettings settings(config);
 	m_dictionary_url = settings.dictionary();
 
 	// Load dice
@@ -249,9 +268,8 @@ void Generator::update()
 		QFile file(dice_path);
 		if (file.open(QFile::ReadOnly | QIODevice::Text)) {
 			QTextStream stream(&file);
-			stream.setCodec("UTF-8");
 			while (!stream.atEnd()) {
-				QStringList line = stream.readLine().split(',', QString::SkipEmptyParts);
+				const QStringList line = stream.readLine().split(',', Qt::SkipEmptyParts);
 				if (line.count() == 6) {
 					dice.append(line);
 				}
@@ -274,77 +292,50 @@ void Generator::update()
 	if (words_path != m_words_path) {
 		m_words_path.clear();
 		m_words.clear();
-		int count = 0;
 
 		// Load cached words
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
-		QString cache_dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/cache";
-#else
-		QString cache_dir = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/cache";
-#endif
+		constexpr quint32 TANGLET_CACHE_MAGICNUMBER = 0x54524945;
+		constexpr quint32 TANGLET_CACHE_VERSION = 2;
 		QString cache_file = QCryptographicHash::hash(words_path.toUtf8(), QCryptographicHash::Sha1).toHex();
-		QFileInfo cache_info(cache_dir + "/" + cache_file);
+		QFileInfo cache_info(m_cache_path + "/" + cache_file);
 		if (cache_info.exists() && (cache_info.lastModified() > QFileInfo(words_path).lastModified())) {
 			QFile file(cache_info.absoluteFilePath());
 			if (file.open(QFile::ReadOnly)) {
 				QDataStream stream(&file);
 				quint32 magic, version;
 				stream >> magic >> version;
-				if ((magic == 0x54524945) && (version == 1)) {
-					stream.setVersion(QDataStream::Qt_4_6);
+				if ((magic == TANGLET_CACHE_MAGICNUMBER) && (version == TANGLET_CACHE_VERSION)) {
+					stream.setVersion(QDataStream::Qt_5_9);
 					stream >> m_words;
-					count = !m_words.isEmpty() * -1;
 				}
 				file.close();
 			}
 		}
 
 		// Load uncached words
-		if (count == 0) {
-			emit optimizingStarted();
+		if (m_words.isEmpty()) {
+			Q_EMIT optimizingStarted();
 
-			QHash<QString, QStringList> words;
-			QByteArray data = gunzip(words_path);
-			QTextStream stream(data);
-			stream.setCodec("UTF-8");
-			while (!stream.atEnd()) {
-				QStringList spellings = stream.readLine().simplified().split(QChar(' '), QString::SkipEmptyParts);
-				if (spellings.isEmpty()) {
-					continue;
-				}
-
-				QString word = spellings.first().toUpper();
-				if (spellings.count() == 1) {
-					spellings[0] = word.toLower();
-				} else {
-					spellings.removeFirst();
-				}
-
-				if (word.length() >= 3 && word.length() <= 25) {
-					words[word] = spellings;
-					count++;
-				}
-			}
-			m_words = Trie(words);
+			m_words = Trie(gunzip(words_path));
 
 			// Cache words
-			if (count) {
-				QDir::home().mkpath(cache_dir);
+			if (!m_words.isEmpty()) {
+				QDir::home().mkpath(m_cache_path);
 				QFile file(cache_info.absoluteFilePath());
 				if (file.open(QFile::WriteOnly)) {
 					QDataStream stream(&file);
-					stream << (quint32)0x54524945;
-					stream << (quint32)1;
-					stream.setVersion(QDataStream::Qt_4_6);
+					stream << TANGLET_CACHE_MAGICNUMBER;
+					stream << TANGLET_CACHE_VERSION;
+					stream.setVersion(QDataStream::Qt_5_9);
 					stream << m_words;
 					file.close();
 				}
 			}
 
-			emit optimizingFinished();
+			Q_EMIT optimizingFinished();
 		}
 
-		if (count) {
+		if (!m_words.isEmpty()) {
 			m_words_path = words_path;
 		} else {
 			return setError(tr("Unable to read word list from file."));
