@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011, 2012, 2013 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "letter.h"
 
@@ -32,10 +19,15 @@
 #include <QPainterPath>
 #include <QPen>
 
+#include <cmath>
+
 //-----------------------------------------------------------------------------
 
 Letter::Letter(const QFont& font, int size, const QPoint& position)
-: m_arrow(0), m_clickable(true), m_position(position) {
+	: m_arrow(nullptr)
+	, m_clickable(true)
+	, m_position(position)
+{
 	QPainterPath path;
 	path.addRoundedRect(0, 0, size, size, 5, 5);
 	setPath(path);
@@ -56,65 +48,69 @@ Letter::Letter(const QFont& font, int size, const QPoint& position)
 	m_cell = new BeveledRect(size + 3, this);
 	m_cell->setPos(-1.5, -1.5);
 	m_cell->setFlag(QGraphicsItem::ItemStacksBehindParent);
-	m_cell->setColor("#0057ae");
+	m_cell->setColor(QColor(0, 0x57, 0xae));
 }
 
 //-----------------------------------------------------------------------------
 
-void Letter::setArrow(qreal angle, int z) {
+void Letter::setArrow(qreal angle, int z)
+{
 	delete m_arrow;
-	m_arrow = 0;
+	m_arrow = nullptr;
 	if (angle < 0.0) {
 		return;
 	}
 
 	QRect rect = sceneBoundingRect().toRect();
-	switch (qRound(angle / 45.0)) {
-		case 0: // right
-			createSideArrow();
-			m_arrow->moveBy(rect.right() - 8, rect.center().y());
-			break;
+	switch (std::lround(angle / 45.0)) {
+	case 0: // right
+		createSideArrow();
+		m_arrow->moveBy(rect.right() - 8, rect.center().y() + 0.5);
+		break;
 
-		case 1: // top right
-			createCornerArrow();
-			m_arrow->moveBy(rect.right() - 8.5, rect.top() + 8.5);
-			m_arrow->setRotation(270);
-			break;
+	case 1: // top right
+		createCornerArrow();
+		m_arrow->moveBy(rect.right() - 8.5, rect.top() + 8.5);
+		m_arrow->setRotation(270);
+		break;
 
-		case 2: // top
-			createSideArrow();
-			m_arrow->moveBy(rect.center().x(), rect.top() + 8);
-			m_arrow->setRotation(270);
-			break;
+	case 2: // top
+		createSideArrow();
+		m_arrow->moveBy(rect.center().x() + 0.5, rect.top() + 8);
+		m_arrow->setRotation(270);
+		break;
 
-		case 3: // top left
-			createCornerArrow();
-			m_arrow->moveBy(rect.left() + 8.5, rect.top() + 8.5);
-			m_arrow->setRotation(180);
-			break;
+	case 3: // top left
+		createCornerArrow();
+		m_arrow->moveBy(rect.left() + 8.5, rect.top() + 8.5);
+		m_arrow->setRotation(180);
+		break;
 
-		case 4: // left
-			createSideArrow();
-			m_arrow->moveBy(rect.left() + 8, rect.center().y());
-			m_arrow->setRotation(180);
-			break;
+	case 4: // left
+		createSideArrow();
+		m_arrow->moveBy(rect.left() + 8, rect.center().y() + 0.5);
+		m_arrow->setRotation(180);
+		break;
 
-		case 5: // bottom left
-			createCornerArrow();
-			m_arrow->moveBy(rect.left() + 8.5, rect.bottom() - 8.5);
-			m_arrow->setRotation(90);
-			break;
+	case 5: // bottom left
+		createCornerArrow();
+		m_arrow->moveBy(rect.left() + 8.5, rect.bottom() - 8.5);
+		m_arrow->setRotation(90);
+		break;
 
-		case 6: // bottom
-			createSideArrow();
-			m_arrow->moveBy(rect.center().x(), rect.bottom() - 8);
-			m_arrow->setRotation(90);
-			break;
+	case 6: // bottom
+		createSideArrow();
+		m_arrow->moveBy(rect.center().x() + 0.5, rect.bottom() - 8);
+		m_arrow->setRotation(90);
+		break;
 
-		case 7: // bottom right
-			createCornerArrow();
-			m_arrow->moveBy(rect.right() - 8.5, rect.bottom() - 8.5);
-			break;
+	case 7: // bottom right
+		createCornerArrow();
+		m_arrow->moveBy(rect.right() - 8.5, rect.bottom() - 8.5);
+		break;
+
+	default:
+		return;
 	};
 
 	m_arrow->setZValue(z + 2);
@@ -122,21 +118,23 @@ void Letter::setArrow(qreal angle, int z) {
 
 //-----------------------------------------------------------------------------
 
-void Letter::setCellColor(const QColor& color) {
+void Letter::setCellColor(const QColor& color)
+{
 	if (color.isValid()) {
 		m_cell->setColor(color, false);
 	} else {
-		m_cell->setColor("#0057ae");
+		m_cell->setColor(QColor(0, 0x57, 0xae));
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-void Letter::setColor(const QColor& color) {
+void Letter::setColor(const QColor& color)
+{
 	QColor darker = color.darker(106);
 	QColor darkest = color.darker(160);
 
-	int height = boundingRect().height();
+	auto height = boundingRect().height();
 
 	QLinearGradient sides(0, 0, 0, height);
 	sides.setColorAt(0, darker);
@@ -148,7 +146,7 @@ void Letter::setColor(const QColor& color) {
 	face_border.setColorAt(1, darker);
 	m_face->setPen(QPen(face_border, 1));
 
-	int radius = height / 2;
+	auto radius = height / 2;
 	QRadialGradient face(radius, radius, radius);
 	face.setColorAt(0, color);
 	face.setColorAt(0.5, color);
@@ -158,20 +156,22 @@ void Letter::setColor(const QColor& color) {
 
 //-----------------------------------------------------------------------------
 
-void Letter::setClickable(bool clickable) {
+void Letter::setClickable(bool clickable)
+{
 	m_clickable = clickable;
 	if (m_clickable) {
 		setCursor(Qt::PointingHandCursor);
 		setColor(Qt::white);
 	} else {
 		unsetCursor();
-		setColor(QColor("#aaa"));
+		setColor(QColor(0xaa, 0xaa, 0xaa));
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-void Letter::setText(const QString& text) {
+void Letter::setText(const QString& text)
+{
 	m_text = text;
 	m_item->setText(m_text);
 	m_item->setPos(boundingRect().center() - m_item->boundingRect().center());
@@ -179,22 +179,25 @@ void Letter::setText(const QString& text) {
 
 //-----------------------------------------------------------------------------
 
-void Letter::mousePressEvent(QGraphicsSceneMouseEvent* event) {
+void Letter::mousePressEvent(QGraphicsSceneMouseEvent* event)
+{
 	Q_UNUSED(event);
 	if (m_clickable) {
-		emit clicked(this);
+		Q_EMIT clicked(this);
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-void Letter::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event) {
+void Letter::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event)
+{
 	event->ignore();
 }
 
 //-----------------------------------------------------------------------------
 
-void Letter::createCornerArrow() {
+void Letter::createCornerArrow()
+{
 	QPainterPath path;
 	path.moveTo(0, 0);
 	path.lineTo(22, 22);
@@ -209,7 +212,8 @@ void Letter::createCornerArrow() {
 
 //-----------------------------------------------------------------------------
 
-void Letter::createSideArrow() {
+void Letter::createSideArrow()
+{
 	QPainterPath path;
 	path.moveTo(0, 0);
 	path.lineTo(22, 0);
