@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "word_tree.h"
 
@@ -31,21 +18,20 @@
 //-----------------------------------------------------------------------------
 
 WordTree::WordTree(QWidget* parent)
-: QTreeWidget(parent), m_active_item(0), m_hebrew(false), m_trie(0) {
+	: QTreeWidget(parent)
+	, m_active_item(nullptr)
+	, m_hebrew(false)
+	, m_trie(nullptr)
+{
 	setColumnCount(3);
 	hideColumn(2);
 	header()->setStretchLastSection(false);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 	header()->setSectionResizeMode(0, QHeaderView::Stretch);
 	header()->setSectionResizeMode(1, QHeaderView::Fixed);
-#else
-	header()->setResizeMode(0, QHeaderView::Stretch);
-	header()->setResizeMode(1, QHeaderView::Fixed);
-#endif
 	header()->hide();
 	setColumnWidth(1, 22);
 
-	setIconSize(QSize(16,16));
+	setIconSize(QSize(16, 16));
 	setMouseTracking(true);
 	setRootIsDecorated(false);
 	setSortingEnabled(true);
@@ -53,12 +39,13 @@ WordTree::WordTree(QWidget* parent)
 	setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
 	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 
-	connect(this, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(onItemClicked(QTreeWidgetItem*, int)));
+	connect(this, &QTreeWidget::itemClicked, this, &WordTree::onItemClicked);
 }
 
 //-----------------------------------------------------------------------------
 
-QTreeWidgetItem* WordTree::addWord(const QString& word) {
+QTreeWidgetItem* WordTree::addWord(const QString& word)
+{
 	QTreeWidgetItem* item = new QTreeWidgetItem(this);
 	item->setText(2, word);
 	if (!m_hebrew) {
@@ -68,19 +55,19 @@ QTreeWidgetItem* WordTree::addWord(const QString& word) {
 		int end = copy.length() - 1;
 		switch (copy.at(end).unicode()) {
 		case 0x05db:
-			copy[end] = 0x05da;
+			copy[end] = QChar(0x05da);
 			break;
 		case 0x05de:
-			copy[end] = 0x05dd;
+			copy[end] = QChar(0x05dd);
 			break;
 		case 0x05e0:
-			copy[end] = 0x05df;
+			copy[end] = QChar(0x05df);
 			break;
 		case 0x05e4:
-			copy[end] = 0x05e3;
+			copy[end] = QChar(0x05e3);
 			break;
 		case 0x05e6:
-			copy[end] = 0x05e5;
+			copy[end] = QChar(0x05e5);
 			break;
 		default:
 			break;
@@ -103,60 +90,70 @@ QTreeWidgetItem* WordTree::addWord(const QString& word) {
 
 //-----------------------------------------------------------------------------
 
-void WordTree::removeAll() {
-	m_active_item = 0;
+void WordTree::removeAll()
+{
+	m_active_item = nullptr;
 	clear();
+	scrollToTop();
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::setDictionary(const QString& url) {
+void WordTree::setDictionary(const QString& url)
+{
 	m_url = QUrl::toPercentEncoding(url, "#$%&+,/:;=?@~");
+	m_url.replace("%25", "%"); // work around Qt's decision to force percent encoding of percent symbol (bug 110446)
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::setHebrew(bool hebrew) {
+void WordTree::setHebrew(bool hebrew)
+{
 	m_hebrew = hebrew;
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::setTrie(const Trie* trie) {
+void WordTree::setTrie(const Trie* trie)
+{
 	m_trie = trie;
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::leaveEvent(QEvent* event) {
+void WordTree::leaveEvent(QEvent* event)
+{
 	QTreeWidget::leaveEvent(event);
-	enterItem(0);
+	enterItem(nullptr);
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::mouseMoveEvent(QMouseEvent* event) {
+void WordTree::mouseMoveEvent(QMouseEvent* event)
+{
 	QTreeWidget::mouseMoveEvent(event);
 	enterItem(itemAt(event->pos()));
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::wheelEvent(QWheelEvent* event) {
+void WordTree::wheelEvent(QWheelEvent* event)
+{
 	QTreeWidget::wheelEvent(event);
-	enterItem(itemAt(event->pos()));
+	enterItem(itemAt(event->position().toPoint()));
 }
 
 //-----------------------------------------------------------------------------
 
-void WordTree::onItemClicked(QTreeWidgetItem* item, int column) {
+void WordTree::onItemClicked(QTreeWidgetItem* item, int column)
+{
 	if (item && column == 1) {
-		QStringList spellings = item->data(1, Qt::UserRole).toStringList();
+		const QStringList spellings = item->data(1, Qt::UserRole).toStringList();
 		QString word = spellings.first();
 
 		if (spellings.count() > 1) {
 			QMenu menu;
-			foreach (const QString& spelling, spellings) {
+			for (const QString& spelling : spellings) {
 				menu.addAction(spelling);
 			}
 			QAction* action = menu.exec(QCursor::pos());
@@ -175,13 +172,14 @@ void WordTree::onItemClicked(QTreeWidgetItem* item, int column) {
 
 //-----------------------------------------------------------------------------
 
-void WordTree::enterItem(QTreeWidgetItem* item) {
+void WordTree::enterItem(QTreeWidgetItem* item)
+{
 	if (m_active_item) {
 		m_active_item->setIcon(1, QIcon(":/empty.png"));
 	}
 	m_active_item = item;
 	if (m_active_item) {
-		m_active_item->setIcon(1, QIcon::fromTheme("accessories-dictionary", QIcon(":/help-browser.png")));
+		m_active_item->setIcon(1, QIcon::fromTheme("accessories-dictionary", QIcon::fromTheme("help-about", QIcon(":/help-browser.png"))));
 	}
 }
 
