@@ -1,109 +1,93 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr" sourcelanguage="en">
+<TS version="2.1" language="fr" sourcelanguage="en">
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="76"/>
-        <location filename="../src/board.cpp" line="859"/>
         <source>Details</source>
         <translation>Détails</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="103"/>
-        <source>Clear</source>
-        <translation>Effacer</translation>
-    </message>
-    <message>
-        <location filename="../src/board.cpp" line="115"/>
         <source>Guess</source>
         <translation>Proposer</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="145"/>
         <source>Found</source>
         <translation>Trouvés</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="282"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="282"/>
         <source>Large</source>
         <translation>Grand</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="301"/>
         <source>Missed</source>
         <translation>Ratés</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="435"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="601"/>
         <source>Success</source>
-        <translation>Succès</translation>
+        <translation>Réussi</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="601"/>
         <source>Game Over</source>
         <translation>Partie terminée</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="780"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 sur %n point</numerusform>
             <numerusform>%1 sur %n points</numerusform>
+            <numerusform>%1 sur %n points</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="782"/>
         <source>3 of %n point(s)</source>
         <translation>
             <numerusform>3 sur %n point</numerusform>
             <numerusform>3 sur %n points</numerusform>
+            <numerusform>3 sur %n points</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="784"/>
         <source>2 of %n point(s)</source>
         <translation>
             <numerusform>2 sur %n point</numerusform>
             <numerusform>2 sur %n points</numerusform>
+            <numerusform>2 sur %n points</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="786"/>
         <source>1 of %n point(s)</source>
         <translation>
             <numerusform>1 sur %n point</numerusform>
             <numerusform>1 sur %n points</numerusform>
+            <numerusform>1 sur %n points</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="788"/>
         <source>0 of %n point(s)</source>
         <translation>
             <numerusform>0 sur %n point</numerusform>
             <numerusform>0 sur %n points</numerusform>
+            <numerusform>0 sur %n points</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="792"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n point</numerusform>
             <numerusform>%n points</numerusform>
+            <numerusform>%n points</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="868"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>Le score maximum a été calculé à partir des 30 mots suivants :</translation>
     </message>
@@ -111,111 +95,101 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="91"/>
         <source>m:ss</source>
         <translation>min:sec</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="152"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n proposition</numerusform>
             <numerusform>%n propositions</numerusform>
+            <numerusform>%n propositions</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="278"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="342"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n blâme</numerusform>
             <numerusform>%n blâmes</numerusform>
+            <numerusform>%n coups</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="517"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="518"/>
         <source>Classic</source>
         <translation>Classique</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Refill</source>
         <translation>Recharge</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Stamina</source>
         <translation>Endurance</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Strikeout</source>
-        <translation>Trois Blâmes</translation>
+        <translation>Trois blâmes</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Allotment</source>
         <translation>Top 30</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Discipline</source>
         <translation>Discipline</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="531"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Minuterie de 30 secondes, rallongée à chaque bonne proposition.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="532"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Minuterie de 3 minutes.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Minuterie de 30 secondes, réinitialisée à chaque bonne proposition.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Minuterie de 45 secondes, gelée à chaque bonne proposition.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>La partie se termine après 3 mauvaises propositions.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Game ends after 30 guesses.</source>
         <translation>La partie se termine après 30 propositions.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Minuterie de 30 secondes, rallongée ou réduite selon la justesse des propositions.</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation>Illimité</translation>
+    </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation>Le jeu se termine une fois tous les mots trouvés.</translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="268"/>
         <source>Unable to read dice from file.</source>
         <translation>Impossible de lire les dés du fichier.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="350"/>
         <source>Unable to read word list from file.</source>
         <translation>Impossible de lire la liste des mots du fichier.</translation>
     </message>
@@ -223,53 +197,42 @@
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Langue de la grille</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Personnalisé</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
         <translation>Parcourir…</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Note :&lt;/b&gt; Ces paramétrages seront effectifs à la prochaine partie.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Langue :</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Dés :</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
         <translation>Liste des mots :</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Dictionnaire :</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
         <translation>Choisir un fichier de dés</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="208"/>
         <source>Choose Word List File</source>
         <translation>Choisir un fichier de liste des mots</translation>
     </message>
@@ -277,22 +240,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="50"/>
         <source>Select application language:</source>
         <translation>Choisissez la Langue de l&apos;application :</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="53"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Langue du Système&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Note</source>
         <translation>Note</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Veuillez redémarrer l&apos;application afin que les modifications soient prises en compte.</translation>
     </message>
@@ -300,429 +259,351 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Nouvelle partie</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation>Abondance de mots :</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation>Longueur minimal des mots :</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation>Faible</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation>Moyenne</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation>Élevée</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation>Aléatoire</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n lettre</numerusform>
             <numerusform>%n lettres</numerusform>
+            <numerusform>%n lettres</numerusform>
         </translation>
     </message>
 </context>
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Plamarès</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nom&lt;b&gt;</translation>
+        <source>Name</source>
+        <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Score&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Résultat</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Date&lt;/b&gt;</translation>
+        <source>Date</source>
+        <translation>Date</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Minuterie&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>n°%1</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
-        <source>Question</source>
-        <translation>Question</translation>
+        <source>Rank</source>
+        <translation>Rang</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
-        <source>Clear high scores?</source>
-        <translation>Effacer les scores ?</translation>
+        <source>Maximum</source>
+        <translation>Maximum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Taille</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Félicitations ! </translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Vous avez battu votre propre score ! </translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Bien joué ! </translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Vous détenez le plus haut score ! </translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation>N. A.</translation>
     </message>
 </context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="283"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pause&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Cliquez pour reprendre la partie.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="313"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Veuillez patienter&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Chargement de la partie…&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>Click to start a new game.</source>
         <translation>Cliquez pour commencer une nouvelle partie.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="324"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Veuillez patienter&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Génération d&apos;une nouvelle grille…&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Veuillez patienter&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimisation de la liste des mots…&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;Game</source>
         <translation>&amp;Partie</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="335"/>
         <source>New &amp;Game...</source>
-        <translation>Nouvelle &amp;partie…</translation>
+        <translation>&amp;Nouvelle partie…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="335"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Maj+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="336"/>
         <source>&amp;New Roll</source>
         <translation>Nouvelle &amp;grille</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Choose...</source>
-        <translation>&amp;Choisir…</translation>
+        <translation>&amp;Importer…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="338"/>
         <source>&amp;Share...</source>
-        <translation>Parta&amp;ger…</translation>
+        <translation>P&amp;artager…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="340"/>
         <source>&amp;End</source>
         <translation>&amp;Terminer</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="343"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pause</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="345"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="350"/>
         <source>&amp;Details</source>
         <translation>&amp;Détails</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="352"/>
         <source>&amp;High Scores</source>
-        <translation>&amp;Palmarès</translation>
+        <translation>Pa&amp;lmarès</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="359"/>
         <source>&amp;Settings</source>
         <translation>P&amp;références</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="360"/>
         <source>Show &amp;Maximum Score</source>
         <translation>Afficher le score &amp;maximum</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="362"/>
         <source>&amp;Never</source>
         <translation>&amp;Jamais</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="363"/>
         <source>&amp;End Of Game</source>
         <translation>En &amp;fin de partie</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="364"/>
         <source>&amp;Always</source>
         <translation>&amp;Toujours</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="372"/>
         <source>Show Missed &amp;Words</source>
         <translation>Afficher les mots &amp;ratés</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Show Word &amp;Counts</source>
         <translation>Afficher le &amp;décompte des mots</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Board Language...</source>
         <translation>Langue de la &amp;grille…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="381"/>
         <source>Application &amp;Language...</source>
         <translation>Langue de l&apos;&amp;application…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="385"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>&amp;Controls</source>
         <translation>&amp;Contrôles</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>&amp;About</source>
         <translation>À &amp;propos</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="390"/>
-        <source>About &amp;Hspell</source>
-        <translation>À propos de &amp;Hspell</translation>
-    </message>
-    <message>
-        <location filename="../src/window.cpp" line="392"/>
         <source>About &amp;Qt</source>
         <translation>À propos de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="394"/>
-        <source>About &amp;SCOWL</source>
-        <translation>À propos de &amp;SCOWL</translation>
-    </message>
-    <message>
-        <location filename="../src/window.cpp" line="476"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="474"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="475"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>Une variante du &lt;a href=&quot;http://fr.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; à un joueur</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="477"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Publié sous la licence GNU &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="478"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
         <translation>La liste des mots anglais a été construite à partir de &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; de Kevin Atkinson</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="479"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>La liste des mots hébreux a été construite à partir de &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El et Dan Kenigsberg</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="486"/>
-        <source>About Hspell</source>
-        <translation>À propos d&apos;Hspell</translation>
-    </message>
-    <message>
-        <location filename="../src/window.cpp" line="493"/>
-        <source>About SCOWL</source>
-        <translation>À propos de SCOWL</translation>
-    </message>
-    <message>
-        <location filename="../src/window.cpp" line="522"/>
         <source>Import Game</source>
         <translation>Importer une partie</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="528"/>
-        <location filename="../src/window.cpp" line="596"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation>Parties Tanglet (*.tanglet)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="547"/>
-        <location filename="../src/window.cpp" line="562"/>
-        <location filename="../src/window.cpp" line="571"/>
-        <location filename="../src/window.cpp" line="809"/>
         <source>Unable to start requested game.</source>
         <translation>Impossible de lancer la partie demandée.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="580"/>
-        <location filename="../src/window.cpp" line="809"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="590"/>
         <source>Export Game</source>
         <translation>Exporter une partie</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="641"/>
         <source>Question</source>
         <translation>Question</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="641"/>
         <source>End the current game?</source>
         <translation>Terminer la partie actuelle ?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="680"/>
         <source>Details</source>
         <translation>Détails</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="686"/>
         <source>Board Size:</source>
         <translation>Dimensions de la grille :</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="686"/>
         <source>Normal</source>
         <translation>Normale</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="686"/>
         <source>Large</source>
         <translation>Grande</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="687"/>
         <source>Word Density:</source>
         <translation>Abondance de mots :</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="688"/>
         <source>Word Length:</source>
         <translation>Longueur des mots :</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="688"/>
         <source>%1 or more letters</source>
         <translation>%1 lettres ou plus</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="689"/>
         <source>Game Type:</source>
         <translation>Type de partie :</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="690"/>
         <source>Description:</source>
         <translation>Description :</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="720"/>
         <source>Controls</source>
         <translation>Contrôles</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="720"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Jeu à la souris :&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Sélectionner un mot :&lt;/b&gt; Cliquer sur les lettres d&apos;un mot.&lt;br&gt;&lt;b&gt;Proposer un mot :&lt;/b&gt; Cliquer sur la dernière lettre sélectionnée.&lt;br&gt;&lt;b&gt;Effacer des lettres :&lt;/b&gt; Cliquer sur une lettre précédemment sélectionnée.&lt;br&gt;&lt;b&gt;Effacer le mot :&lt;/b&gt; Cliquer deux fois sur la première lettre sélectionnée.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Jeu au clavier :&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Sélectionner un mot :&lt;/b&gt; Taper les lettres du mot.&lt;br&gt;&lt;b&gt;Proposer le mot :&lt;/b&gt; Presser Entrée.&lt;br&gt;&lt;b&gt;Effacer le mot :&lt;/b&gt; Presser Ctrl+Retour arrière.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="39"/>
         <source>Letters:</source>
         <translation>Lettres :</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="39"/>
         <source>Found:</source>
         <translation>Trouvés :</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="115"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="120"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2 / %3&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation>%1&lt;br&gt;%2 / %3</translation>
     </message>
@@ -730,12 +611,23 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="98"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n point</numerusform>
             <numerusform>%n points</numerusform>
+            <numerusform>%n points</numerusform>
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation>Jeu de recherche de mots</translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation>Un fichier de jeu à lire.</translation>
+    </message>
+</context>
 </TS>
